package MooseX::Attribute::ENV;


=head1 NAME

MooseX::Attribute::ENV - Set default of an attribute to a value from %ENV

=head1 VERSION

Version 0.01

=cut

our $VERSION = '0.01';

=head1 SYNOPSIS

The following is example usage for this component.

	package Myapp::MyClass;
	
	use Moose;
	use MooseX::Attribute::ENV;
	
	has 'username' => (traits => ['ENV']);
	has 'password' => (traits => ['ENV'], env_key => 'GLOBAL_PASSWORD');
	has 'last_login' => (traits => ['ENV'], default => sub {localtime} );

Please see the test cases for more detailed examples.

=head1 DESCRIPTION

This is a L<Moose> attribute trait that you use when you want the default value
for an attribute to be populated from the %ENV hash.  So, for example if you
have set the environment variable MYAPP_MYCLASS_USERNAME = 'John' you can do:

	package MyApp::MyClass;
	
	use Moose;
	use MooseX::Attribute::ENV;
	
	has 'username' => (is=>'ro', traits=>['ENV']);
	
	package main;
	
	my $myclass = MyApp::MyClass->new();
	
	print $myclass->username; # STDOUT => 'John';

This is basically similar functionality to something like:

	has 'attr' => (
		is=>'ro',
		default=> sub {
			$ENV{uc __PACKAGE_.'attr'};
		},
	);

but this module has a few other features that offer merit, as well as being a
simple enough attribute trait that I hope it can serve as a learning tool.  It
also does it's best to respect existing builders, defaults and lazy_build
options.

=head1 METHODS

This module defines the following methods.

=head1 AUTHOR

John Napiorkowski, C<< <jjnapiork at cpan.org> >>

=head1 BUGS

Please report any bugs or feature requests to:

	C<MooseX-Attribute-ENV at rt.cpan.org>

or through the web interface at:

	L<http://rt.cpan.org/NoAuth/ReportBug.html?Queue=MooseX-Attribute-ENV>

I will be notified, and then you'll automatically be notified of progress on 
your bug as I make changes.

=head1 SUPPORT

You can find documentation for this module with the perldoc command.

    perldoc MooseX::Attribute::ENV

You can also look for information at:

=over 4

=item * RT: CPAN's request tracker

L<http://rt.cpan.org/NoAuth/Bugs.html?Dist=MooseX-Attribute-ENV>

=item * AnnoCPAN: Annotated CPAN documentation

L<http://annocpan.org/dist/MooseX-Attribute-ENV>

=item * CPAN Ratings

L<http://cpanratings.perl.org/d/MooseX-Attribute-ENV>

=item * Search CPAN

L<http://search.cpan.org/dist/DBIx-Class-PopulateMore>

=back

=head1 LICENSE

This program is free software; you can redistribute it and/or modify it
under the same terms as Perl itself.

=cut

1;
